import lodash from 'lodash';
import { formatDatetime } from '@billogram/format';

function createMatchesValueFunc(value, type) {
  return function matchesValue(term) {
    switch (type) {
      case 'date':
        {
          return term.replace(/[\u002D\u2010\u2212]/g, "\u2011") === formatDatetime(value, {
            locale: 'sv'
          });
        }

      case 'money':
        {
          var amount = value;
          return amount.value !== null && amount.value !== void 0 && term === amount.value.toString();
        }

      default:
        {
          var re = new RegExp(lodash.escapeRegExp(term), 'i');
          return re.test(value);
        }
    }
  };
}

function getTerms(definition, query) {
  if (Array.isArray(query)) {
    if (definition.advancedSearchOnly === true) {
      return [];
    }

    return query;
  }

  if (definition.getAdvancedSearchValue !== void 0) {
    var result = definition.getAdvancedSearchValue(query);
    var values = !Array.isArray(result) ? [result] : result;
    return values.filter(function (value) {
      return value !== void 0;
    });
  }

  return [];
}

export default function toSearchField(definition, data, query) {
  var actualValue = definition.getValue(data);
  var value = actualValue !== null && actualValue !== void 0 ? actualValue : '';
  var type = definition.type !== void 0 ? definition.type : 'default';
  var matchesValue = createMatchesValueFunc(value, type);
  var terms = getTerms(definition, query);
  var matchingTerms = terms.filter(matchesValue);
  return {
    key: definition.key,
    matchingTerms: matchingTerms,
    title: definition.title,
    type: type,
    value: value
  };
}
//# sourceMappingURL=toSearchField.js.map