import React from 'react';
import { FoundationListDataProviderData, FoundationListDataProviderFetch, FoundationListDataProviderFetchInitialHandler, FoundationListDataProviderFetchMoreHandler, FoundationListDataProviderFetchSortHandler, FoundationListDataProviderResult, FoundationListDataProviderRowType, FoundationListDataProviderSortDirection, FoundationListDataProviderUpdateItemHandler } from '@billogram/foundation-list-data-provider';
import { Money } from '@billogram/money';
export interface FoundationTableRowPropsType<TRowData, TAdditionalRowData = unknown> {
    additionalData: TAdditionalRowData;
    data: TRowData;
}
export declare type FoundationTableRowComponentType<TRowData, TAdditionalRowData = unknown> = React.ComponentType<FoundationTableRowPropsType<TRowData, TAdditionalRowData>>;
export interface FoundationTableRowGroupContextType<TRowData> {
    columns: FoundationTableColumnDefinition[];
    collapse: () => void;
    expand: () => void;
    highlight: () => void;
    isExpanded: boolean;
    isHighlighted: boolean;
    unhighlight: () => void;
    refetchTable: FoundationListDataProviderFetchInitialHandler;
    toggleExpanded: () => void;
    toggleHighlighted: () => void;
    update: (item: TRowData) => void;
}
export declare type FoundationTableRowExpandResultGroupComponentType<TRowData, TAdditionalRowData = unknown> = React.ComponentType<FoundationTableRowPropsType<TRowData, TAdditionalRowData>>;
export interface FoundationTableColumnDefinition {
    name: string;
    sortByColumnKey?: string;
    title?: React.ReactNode;
}
export interface FoundationTableSortHandler {
    (sortBy: string): void;
}
export interface FoundationSearchResultOverviewItem {
    count?: number;
    key: string;
    title: string;
    to: {
        pathname: string;
        query?: Record<string, string>;
    };
}
export declare type FoundationTableRowSearchFieldValue = Money | number | string;
export declare type FoundationTableRowSearchFieldDefinitionParamsType = 'date' | 'default' | 'money';
export interface FoundationTableRowSearchFieldDefinitionParams<TData, TAdvancedSearchQueryParams = unknown> {
    advancedSearchOnly?: boolean;
    getAdvancedSearchValue?: (query: TAdvancedSearchQueryParams) => Array<string | undefined> | string | undefined;
    getValue: (data: TData) => FoundationTableRowSearchFieldValue | null | undefined;
    key: string;
    title: React.ReactNode;
    type?: FoundationTableRowSearchFieldDefinitionParamsType;
}
export interface FoundationTableRowSearchField {
    key: string;
    matchingTerms: string[];
    title: React.ReactNode;
    type: FoundationTableRowSearchFieldDefinitionParamsType;
    value: FoundationTableRowSearchFieldValue;
}
export declare type FoundationTableRowSearchGeneralQuery = string[];
export declare type FoundationTableRowSearchAdvancedQueryParams<K extends string> = Partial<Record<K, string>>;
export declare type FoundationTableRowSearchQuery<T extends FoundationTableRowSearchAdvancedQueryParams<Extract<keyof T, string>> = {}> = FoundationTableRowSearchGeneralQuery | T;
export interface FoundationTableRowSearchFieldDefinition<TData, TAdvancedSearchQueryParams = unknown> {
    (data: TData, query: FoundationTableRowSearchQuery<TAdvancedSearchQueryParams>): React.ReactNode;
}
export interface FoundationTableMenuItemAction {
    disabled?: boolean;
    onClick: () => void;
    text: string;
    type: 'action';
    value: string;
}
export interface FoundationTableMenuItemLink {
    disabled?: boolean;
    text: string;
    href: string;
    type: 'link';
    value: string;
}
export interface FoundationTableMenuItemRoute {
    disabled?: boolean;
    text: string;
    to: string;
    type: 'route';
    value: string;
}
export declare type FoundationTableMenuItem = FoundationTableMenuItemAction | FoundationTableMenuItemLink | FoundationTableMenuItemRoute;
export interface FoundationTableProps<TRowData, TAdditionalRowData = unknown, TAdvancedSearchQueryParams = unknown> {
    additionalRowData?: TAdditionalRowData;
    columns?: FoundationTableColumnDefinition[];
    EmptyState?: React.ComponentType<{}>;
    fetchInitial?: FoundationListDataProviderFetchInitialHandler;
    fetchMore?: FoundationListDataProviderFetchMoreHandler;
    fetchSort?: FoundationListDataProviderFetchSortHandler;
    isSearchResult?: boolean;
    searchFields?: Array<FoundationTableRowSearchFieldDefinition<TRowData, TAdvancedSearchQueryParams>>;
    searchQuery?: FoundationTableRowSearchQuery<TAdvancedSearchQueryParams>;
    subTitle?: React.ReactNode;
    table: FoundationListDataProviderResult<TRowData>;
    tableName?: string;
    TableRow?: FoundationTableRowComponentType<TRowData, TAdditionalRowData>;
    TableRowExpandResultGroup?: FoundationTableRowExpandResultGroupComponentType<TRowData, TAdditionalRowData>;
    title?: React.ReactNode;
    updateItem?: FoundationListDataProviderUpdateItemHandler<TRowData>;
}
export interface FoundationTableCaptionProps {
    subTitle: React.ReactNode;
    title: React.ReactNode;
}
export declare type FoundationTableDataConsumerProps<TRowData, TAdditionalRowData = unknown, TAdvancedSearchQueryParams = unknown> = Pick<FoundationTableProps<TRowData, TAdditionalRowData, TAdvancedSearchQueryParams>, 'additionalRowData' | 'columns' | 'EmptyState' | 'isSearchResult' | 'searchFields' | 'searchQuery' | 'subTitle' | 'tableName' | 'TableRow' | 'TableRowExpandResultGroup' | 'title'>;
export interface FoundationTableDataProviderProps<TRowData, TData extends FoundationListDataProviderData<TRowData> = FoundationListDataProviderData<TRowData>, TOptions = never> {
    children?: React.ReactNode;
    fetchData: FoundationListDataProviderFetch<TRowData, TData>;
    initialFetchDataOptions?: TOptions;
    initialLimit?: number;
    initialSortBy?: string;
    initialSortDirection?: FoundationListDataProviderSortDirection;
}
export interface FoundationTableFetchMoreButtonsProps {
    fetchMore: (limit: number) => void;
    isFetching: boolean;
    itemsLeftToFetch: number;
}
export interface FoundationTableStateProps {
    children?: React.ReactNode;
    description?: React.ReactNode;
    title: React.ReactNode;
    ui?: 'empty' | 'error';
}
export interface FoundationTableRowExpandResultProps {
    children: React.ReactNode;
    hasFetchError?: boolean;
    isFetching?: boolean;
    title?: React.ReactNode;
}
export interface FoundationTableRowExpandResultGroupProps<T> {
    children: React.ReactNode;
}
export interface FoundationTableRowExpandResultPropertyProps {
    children: React.ReactNode;
    title: React.ReactNode;
}
export interface FoundationTableRowExpandResultPropertyGroupProps {
    children: React.ReactNode;
}
export interface FoundationTableRowExpandResultPropertyGroupSectionProps {
    children: React.ReactNode;
}
export interface FoundationTableHeaderProps {
    columns: FoundationTableColumnDefinition[];
    currentSortBy: string;
    currentSortDirection: FoundationListDataProviderSortDirection;
    isFetching: boolean;
    shouldDisableSorting: boolean;
    sort: FoundationTableSortHandler;
}
export interface FoundationTableHeaderCellProps {
    children?: React.ReactNode;
    columnName: string;
    currentSortBy: string;
    currentSortDirection: FoundationListDataProviderSortDirection;
    isFetching: boolean;
    shouldDisableSorting: boolean;
    sort: FoundationTableSortHandler;
    sortByColumnKey?: string;
}
export interface FoundationTableHeaderRowProps {
    children: React.ReactNode;
}
export interface FoundationTableCellProps {
    children: React.ReactNode;
    columnName: string;
}
export interface FoundationTableCellAsyncButtonProps<T, U> {
    asyncAction: () => Promise<T>;
    children: React.ReactNode;
    columnName: string;
    onAsyncActionSuccess?: (data: T) => void;
    onAsyncActionError?: (e: U) => void;
    visible?: boolean;
}
export interface FoundationTableCellExpandButtonProps {
    columnName: string;
}
export interface FoundationTableCellLightboxButtonProps {
    children: React.ReactNode;
    columnName: string;
}
export interface FoundationTableCellLinkButtonProps {
    columnName: string;
    href: string;
    ui: 'download';
}
export interface FoundationTableCellMainValueProps {
    children: React.ReactNode;
    columnName: string;
    to: string;
}
export interface FoundationTableCellMenuProps {
    columnName: string;
    options: FoundationTableMenuItem[];
}
export interface FoundationTableCellRouteButtonProps {
    columnName: string;
    to: string;
    ui: 'edit' | 'view';
}
export interface FoundationTableCellSingleControlGroupProps {
    children?: React.ReactNode;
}
export interface FoundationTableCellValueProps {
    children: React.ReactNode;
    columnName: string;
}
export interface FoundationTableRowProps {
    children: React.ReactNode;
}
export interface FoundationTableRowGroupProps<TRowData, TAdditionalRowData = unknown, TAdvancedSearchQueryParams = unknown> {
    additionalData?: TAdditionalRowData;
    columns: FoundationTableColumnDefinition[];
    fetchInitial: FoundationListDataProviderFetchInitialHandler;
    isFetching: boolean;
    isLast: boolean;
    isOdd: boolean;
    isSearchResult: boolean;
    item: FoundationListDataProviderRowType<TRowData>;
    searchFields?: Array<FoundationTableRowSearchFieldDefinition<TRowData, TAdvancedSearchQueryParams>>;
    searchQuery: FoundationTableRowSearchQuery<TAdvancedSearchQueryParams>;
    TableRow: FoundationTableRowComponentType<TRowData, TAdditionalRowData>;
    TableRowExpandResultGroup?: FoundationTableRowExpandResultGroupComponentType<TRowData, TAdditionalRowData>;
    updateItem: FoundationListDataProviderUpdateItemHandler<TRowData>;
}
export interface FoundationTableRowSearchResultProps {
    children: React.ReactNode;
    title: React.ReactNode;
}
export interface FoundationTableRowSearchResultGroupProps<TData, TAdvancedSearchQueryParams> {
    data: TData;
    fields: Array<FoundationTableRowSearchFieldDefinition<TData, TAdvancedSearchQueryParams>>;
    query: FoundationTableRowSearchQuery<TAdvancedSearchQueryParams>;
}
export interface FoundationSearchResultOverviewProps {
    isFetching?: boolean;
    items?: FoundationSearchResultOverviewItem[];
}
